<?php

namespace Teknisa\PED\Modules\Pedidos\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Doctrine\ORM\Query\ResultSetMapping;

class Ped04900RecalculoComissaoVendedorFactory {
    
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function getComissaoVendedor($row){
        
        $sql = "SELECT
                   VI.CDFILIAL, VI.NRPEDIDO, VI.NRITEMPED, VI.CDVENDEDOR,
                   IP.VRPREUNITPED, IP.CDPRODUTO, VI.VRPECOMITPED,
                   IP.IDSITITEMPED
                FROM
                   ITEMPEDIDO IP, VENDITEMPED VI, PRODUTO P
                WHERE
                   (IP.CDFILIAL = :P_CDFILIAL)          AND
                   (IP.IDSITITEMPED IN ('1', '2', '3')) AND
                   (IP.CDPRODUTO = P.CDPRODUTO) AND
                   (P.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) AND
                   (VI.CDFILIAL  = IP.CDFILIAL) AND
                   (VI.NRPEDIDO  = IP.NRPEDIDO) AND
                   (VI.NRITEMPED = IP.NRITEMPED)
                ORDER BY VI.CDVENDEDOR, IP.CDPRODUTO";
        
        $params = array('P_CDFILIAL'  => $row['CDFILIAL'],
						'P_CDPRODINI' => $row['CDPRODINI'],
						'P_CDPRODFIN' => $row['CDPRODFIN']
		);
		$std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function procGeraComissaoVend($item, $cdoperador){
        try {

            $this->connection->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_COMISSAOVEND'); //('GERA_COMISSAOVEND')
            $procedure->addParam(new Param('P_CDFILIAL'    , Param::PARAM_INPUT, $item['CDFILIAL']        , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDO'    , Param::PARAM_INPUT, $item['NRPEDIDO']        , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDVENDEDOR'  , Param::PARAM_INPUT, $item['CDVENDEDOR']      , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDOPERADOR'  , Param::PARAM_INPUT, $cdoperador              , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRITEMPED'   , Param::PARAM_INPUT, $item['NRITEMPED']       , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDSITITEMPED', Param::PARAM_INPUT, $item['IDSITITEMPED']    , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRODUTO'   , Param::PARAM_INPUT, $item['CDPRODUTO']       , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_VRPREUNITPED', Param::PARAM_INPUT, $item['VRPREUNITPED']    , Param::PARAM_TYPE_STR));
            $procedure->execute(); 
            
            $this->entityManager->getConnection()->commit();
 
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
            $this->entityManager->rollback();
            throw $e;
    	}
    }
}